@@ -1,3 +1,5 @@
+import json
+
 from dataclasses import asdict, is_dataclass
 from enum import Enum, auto
 from functools import wraps
@@ -76,6 +78,9 @@ def check_response(result, response_model: Dict[int, PydanticModel]):
     else:
         value = result
 
+    if isinstance(value, Response):
+        value = value.get_json()
+
     status = 200
     if status_or_headers is not None and not isinstance(
         status_or_headers, (Headers, dict, list)
